@@ -1,9 +1,9 @@
 package Test::Mocha::MethodCall;
 # ABSTRACT: Objects to represent method calls
-$Test::Mocha::MethodCall::VERSION = '0.61';
+$Test::Mocha::MethodCall::VERSION = '0.62';
+use parent 'Test::Mocha::Method';
 use strict;
 use warnings;
-use parent qw( Test::Mocha::Method );
 
 sub new {
     # uncoverable pod
